/*
 * @(#)FSBgImagePanel.java 1.0 00/11/19
 *
 * This panel displays a full screen image that covers all windows except
 * the installers.  It is designed to be the first panel in Pre-Install.
 * It requires that two InstallAnywhere variables (FSBGI_GRADIENT,
 * FSBGI_IMAGE) are set prior to calling the panel.
 *
 * The variable FSBGI_GRADIENT describes how you would like the gradient,
 * if any, to appear.  It is set with a comma separated list of parameters.
 * There are seven required parameters.  The first is the mode of the
 * gradient, the rest are the red, green and blue components of the start
 * and end colors for the gradient.  The mode parameter is an integer from
 * 1 to 5.
 *		1 = No gradient, interpret next three integers as the background
 * 			color of the full screen panel.
 *		2 = Gradient is top to bottom.
 *		3 = Gradient is bottom to top.
 *		4 = Gradient is left to right.
 *		5 = Gradient is right to left.
 *
 * The variable FSBGI_IMAGE describes how you would like the image, if any,
 * to appear.  It is set with two parameters separated with a comma. The
 * first is an integer from 1 to 8. The second is a string that is the
 * path within the customcode zip of the image to display. The mode is:
 *		 1 = Do not display an image.
 *		 2 = Stretch the image to fill the entire screen.
 *		 3 = Display image in upper left corner.
 *		 4 = Display image in upper right corner.
 *		 5 = Display image in lower left corner.
 *		 6 = Display image in lower right corner.
 *		 7 = Center the image on the screen.  This will make the image
 *			 appear behind the installer panel, and thus the image
 *			 should be larger than the installer panel.
 *		 8 = Tile the image to fill the screen.
 *
 *
 */

package com.zerog.ia.customcode.installpanels;

import com.zerog.ia.api.pub.CustomCodePanel;
import com.zerog.ia.api.pub.CustomCodePanelProxy;
import java.awt.*;
import java.awt.geom.Rectangle2D;
import java.io.PrintStream;
import java.net.URL;
import java.util.StringTokenizer;

public class FSBgImagePanel extends CustomCodePanel
{

    public FSBgImagePanel()
    {
        isSetup = false;
    }

	/**
	 * This method gets called prior to the Panel being displayed.
	 * This is useful for initializing the contained Components; In fact,
	 * all of the Components may be instantiated in this method.
	 *
	 * It is very important that this method returns quickly so that the
	 * CustomCodePanel may be displayed when needed.  If it is necessary to
	 * do some lengthy processing, it must be done in a separate Thread.
	 * <br>
	 * <br>
	 * NOTE:  If <code>setupUI():boolean</code> returns <code>false</code>,
	 *        to indicate that the CustomCodePanel should <i>not</i> be displayed,
	 *        the installation manager will go on without calling any of the
	 *        other methods in <code>CustomCodePanel</code>.
	 * <br>
	 *
	 * @param customCodePanelProxy Provides access to designer-specified
	 *                          resources, system and user-defined
	 *                          variables, and international resources.
	 *
	 * @return <code>true</code> if the Panel should be displyed,
	 *         <code>false</code> otherwise.  By default, this
	 *         method returns <code>false</code>.
	 *
	 * @see com.zerog.ia.api.pub.CustomCodePanelProxy
	 */

    public boolean setupUI(CustomCodePanelProxy customcodepanelproxy)
    {
        if(!isSetup)
        {
            final String GradientInfo = customcodepanelproxy.substitute("$FSBGI_GRADIENT$");
            final String ImageInfo = customcodepanelproxy.substitute("$FSBGI_IMAGE$");

			// if either of the variables not set tell the user so.

            if(GradientInfo.equals("") || ImageInfo.equals(""))
                System.out.println("One or more of the variables not set! I won't work as expected...");

			// we use an anonymous inner class so that we can override it's paint method.
			// but first we determine which platform were running on, 'cause Windows works
			// better using a window and Unix works better with a frame.

            String s1 = System.getProperty("os.name");
            System.out.println(s1);
            if(s1.indexOf("Windows") >= 0 || s1.indexOf("Mac") >= 0)
            {
                BigFrame = new Window(new Frame());
                System.out.println("We did a Window");
            }
			else
            {
                BigFrame = new Frame();
                System.out.println("We did a Frame");
            }
            Panel panel = new Panel()
			{

                public void paint(Graphics g)
                {

					// set variables to default values

					float f = (float)(d.width / 256) + 1.0F;
                    float f1 = (float)(d.height / 256) + 1.0F;
                    int ColorSegment[] = {
                        1, 0, 0, 0, 0, 0, 0
                    };
                    float f2 = 0.0F;
                    float f3 = 0.0F;
                    float f4 = 0.0F;
                    int i = 0;
                    int j = 0;
                    int k = 0;
                    int l = 0;
                    int i1 = 3;
                    int j1 = 0;
                    int k1 = 0;
                    Graphics2D graphics2d = (Graphics2D)g;

					// read the color values and mode of the gradient if FSBGI_GRADIENT set properly.

                    if(!GradientInfo.equals(""))
                    {
                        for(StringTokenizer stringtokenizer = new StringTokenizer(GradientInfo, ","); stringtokenizer.hasMoreTokens();)
                        {
                            ColorSegment[i] = Integer.parseInt(stringtokenizer.nextToken());
                            i++;
                        }

                    }

					// read the image mode and get the image if FSBGI_IMAGE set properly.

                    System.out.println("Reading image info");
                    if(!ImageInfo.equals(""))
                    {
                        StringTokenizer stringtokenizer1 = new StringTokenizer(ImageInfo, ",");
                        i1 = Integer.parseInt(stringtokenizer1.nextToken());
                        System.out.println(i1 + "");

						// get image only if the ImageMode variable tells us to.

                        if(i1 >= 2)
                        {
                            imageURL = ClassLoader.getSystemResource(stringtokenizer1.nextToken());
                            picture = Toolkit.getDefaultToolkit().getImage(imageURL);
                        }
                    }

                    // Now based on the initial parameter we decide what direction to show gradient in.

                    switch(ColorSegment[0])
                    {

					// Display no gradient, set background to param 2 - 4.

                    case 1: // '\001'
                        System.out.println("Setting background color...");
                        setBackground(new Color(ColorSegment[1], ColorSegment[2], ColorSegment[3]));
                        break;

					// Display gradient top to bottom, params 2 - 4 = start color, 5 -7 end color.

                    case 2: // '\002'
                        System.out.println("Displaying Gradient top to bottom...");
						doGradient(d.width / 2, 0.0F, new Color(ColorSegment[1], ColorSegment[2], ColorSegment[3]), d.width / 2, d.height, new Color(ColorSegment[4], ColorSegment[5], ColorSegment[6]),graphics2d);
                        break;

					// Display gradient bottom to top, colors as in case 2.

                    case 3: // '\003'
                        System.out.println("Displaying Gradient bottom to top...");
						doGradient(d.width / 2, 0.0F, new Color(ColorSegment[4], ColorSegment[5], ColorSegment[6]), d.width / 2, d.height, new Color(ColorSegment[1], ColorSegment[2], ColorSegment[3]),graphics2d);
                        break;

                    // Display gradient left to right. colors as in case 2.

					case 4: // '\004'
                        System.out.println("Displaying Gradient left to right...");
						doGradient(0.0F, d.height / 2, new Color(ColorSegment[1], ColorSegment[2], ColorSegment[3]), d.width, d.height / 2, new Color(ColorSegment[4], ColorSegment[5], ColorSegment[6]),graphics2d);
                        break;

                    // Display gradient right to left. colors as in case 2.

					case 5: // '\005'
                        System.out.println("Displaying Gradient right to left...");
						doGradient(0.0F, d.height / 2, new Color(ColorSegment[4], ColorSegment[5], ColorSegment[6]), d.width, d.height / 2, new Color(ColorSegment[1], ColorSegment[2], ColorSegment[3]),graphics2d);
                        break;

                    // Improper value was set for mode.

					default:
                        System.out.println("Illegal mode parameter specified!\n Can't display gradient!");
                        break;
                    }

					// We get the width and height of the picture only if the mode variable says that there
					// is a picture.

                    if(i1 >= 2)
                    {
                        j1 = picture.getWidth(this);
                        k1 = picture.getHeight(this);
                    }

					//Now based on ImageMode we decide if and how to display the image.

                    switch(i1)
                    {

					//Don't display an image.

                    case 1: // '\001'
                        System.out.println("You chose not to show an image...");
                        break;

					//Stretch the image to fill the screen.

					case 2: // '\002'
                        System.out.println("Streching image to fill screen...");
                        g.drawImage(picture, 0, 0, d.width, d.height, this);
                        break;

					//Show image, over gradient, in upper left.

					case 3: // '\003'
                        System.out.println("Displaying image in upper left corner...");
                        g.drawImage(picture, 0, 0, this);
                        break;

					//Show image, over gradient, in upper right.

					case 4: // '\004'
                        System.out.println("Displaying image in upper right corner...");
                        g.drawImage(picture, d.width - j1, 0, this);
                        break;

                    //Show image, over gradient, in lower left.

					case 5: // '\005'
                        System.out.println("Displaying image in lower left corner...");
                        g.drawImage(picture, 0, d.height - k1, this);
                        break;

                    //Show image, over gradient, in lower right.

					case 6: // '\006'
                        System.out.println("Displaying image in lower right corner...");
                        g.drawImage(picture, d.width - j1, d.height - k1, this);
                        break;

                    //Show image, over gradient, in center.

					case 7: // '\007'
                        System.out.println("Displaying image in center...");
                        g.drawImage(picture, d.width / 2 - j1 / 2, d.height / 2 - k1 / 2, this);
                        break;

                    //Tile image to fill screen.

					case 8: // '\b'
                        System.out.println("Tiling image...");
                        int l1 = d.width / j1;
                        int i2 = d.height / k1;
                        if(d.width % j1 != 0)
                            l1++;
                        if(d.height % k1 != 0)
                            i2++;
                        for(int j2 = 0; j2 < i2; j2++)
                        {
                            for(int k2 = 0; k2 < l1; k2++)
                                g.drawImage(picture, k2 * j1, j2 * k1, this);

                        }
						break;

                    // Improper value set for ImageMode.

                    default:
                        System.out.println("Illegal image mode value, I can't display image!");
                        break;
                    }
                }

				public void doGradient(float xStart, float yStart, Color SColor, float xEnd, float yEnd, Color EColor, Graphics2D graphics2d)
				{
					Rectangle rectangle = new Rectangle(0, 0, d.width, d.height);
					GradientPaint gradientpaint = new GradientPaint(xStart, yStart, SColor, xEnd, yEnd, EColor, true);
                    graphics2d.setPaint(gradientpaint);
                    rectangle.setFrame(0.0D, 0.0D, d.width, d.height);
                    graphics2d.fill(rectangle);
				}

                Dimension d = Toolkit.getDefaultToolkit().getScreenSize();
                URL imageURL;
                Image picture;
			};


            Dimension dimension = Toolkit.getDefaultToolkit().getScreenSize();
            BigFrame.setSize(dimension.width, dimension.height);
            BigFrame.setLocation(0, 0);
            panel.setBackground(Color.black);
            panel.setBounds(0, 0, dimension.width, dimension.height);
            BigFrame.add(panel);
            BigFrame.show();

			// If running on linux we don't call this to front as successive calling of panels to front
			// seems to fail.

            if(s1.indexOf("Windows") >= 0 || s1.indexOf("Mac") >= 0)
                BigFrame.toFront();

			// Set the window to disabled so that the user cannot bring it in front of the installer
			// this does not seem to work on Unix platforms.

            BigFrame.setEnabled(false);
        }
        title = customcodepanelproxy.substitute("$PRODUCT_NAME$");
        if(!isSetup)
        {
            isSetup = true;
            return true;
        }
		else
        {
            return false;
        }
    }

	/**
	 * This method gets called immediately after the Panel is displayed.
	 * This is useful for doing some processing while the Panel is displayed,
	 * without having to wait for <code>okToContinue</code> to be called.
	 * Of course, this method will never be called if <code>setupUI()</code>
	 * returns <code>false</code> to indicate that this
	 * <code>CustomCodePanel</code> should not be displayed.
	 * The default implementation has an empty body.  Classes that extend
	 * CustomCodePanel may override this method if they wish to be notified
	 * when the Panel is displayed.
	 *
	 * The method is optional and does not need to be implemented.
	 *
	 * @see #okToContinue
	 */

    public void panelIsDisplayed()
    {

		// we call the next panel, so that the blank panel is not displayed.

		clickNextButton();

		// we need to climb the parent tree till we get a Frame object to call to front
		// so that the Installer panel is in front of the full screen window.

        Container container = getParent();
        System.out.println("Walking up the parent tree..." + container);
        while(!(container instanceof Frame))
        {
            container = container.getParent();
            System.out.println("" + container + "\n\n");
        }
        Frame frame = (Frame)container;
        frame.toFront();
    }

	/**
	 * This method returns the String to be displayed on the installation
	 * step of which this Panel will be contained.
	 *
	 */

    public String getTitle()
    {
        return title;
    }

    boolean isSetup;
    private static CustomCodePanelProxy ipGlobal;
    private static boolean installTime;
    private String title;
    Window BigFrame;
}
