/*
 * @(#)ReadMePanel.java 1.0 00/11/19
 *
 * This panel displays a full screen image that covers all windows except
 * the installers.  It is designed to be the first panel in Pre-Install.
 * It requires that two InstallAnywhere variables (FSBGI_GRADIENT,
 * FSBGI_IMAGE) are set prior to calling the panel.
 *
 * The variable FSBGI_GRADIENT describes how you would like the gradient,
 * if any, to appear.  It is set with a comma separated list of parameters.
 * There are seven required parameters.  The first is the mode of the
 * gradient, the rest are the red, green and blue components of the start
 * and end colors for the gradient.  The mode parameter is an integer from
 * 0 to 4.
 *		0 = No gradient, interpret next three integers as the background
 * 			color of the full screen panel.
 *		1 = Gradient is top to bottom.
 *		2 = Gradient is bottom to top.
 *		3 = Gradient is left to right.
 *		4 = Gradient is right to left.
 *
 * The variable FSBGI_IMAGE describes how you would like the image, if any,
 * to appear.  It is set with two parameters separated with a comma. The
 * first is an integer from -1 to 6. The second is a string that is the
 * path within the customcode zip of the image to display. The mode is:
 *		-1 = Do not display an image.
 *		 0 = Stretch the image to fill the entire screen.
 *		 1 = Display image in upper left corner.
 *		 2 = Display image in upper right corner.
 *		 3 = Display image in lower left corner.
 *		 4 = Display image in lower right corner.
 *		 5 = Center the image on the screen.  This will make the image
 *			 appear behind the installer panel, and thus the image
 *			 should be larger than the installer panel.
 *		 6 = Tile the image to fill the screen.
 *
 */

package com.zerog.ia.customcode.installpanels;

import com.zerog.ia.api.pub.CustomCodePanel;
import com.zerog.ia.api.pub.CustomCodePanelProxy;
import com.zerog.ia.api.pub.GUIAccess;
import java.util.StringTokenizer;
import java.awt.*;
import java.io.*;
import java.net.*;

public class FSBgImagePanel extends CustomCodePanel
{

	public FSBgImagePanel()
    {
        isSetup = false;
    }

	/**
	 * This method gets called prior to the Panel being displayed.
	 * This is useful for initializing the contained Components; In fact,
	 * all of the Components may be instantiated in this method.
	 *
	 * It is very important that this method returns quickly so that the
	 * CustomCodePanel may be displayed when needed.  If it is necessary to
	 * do some lengthy processing, it must be done in a separate Thread.
	 * <br>
	 * <br>
	 * NOTE:  If <code>setupUI():boolean</code> returns <code>false</code>,
	 *        to indicate that the CustomCodePanel should <i>not</i> be displayed,
	 *        the installation manager will go on without calling any of the
	 *        other methods in <code>CustomCodePanel</code>.
	 * <br>
	 *
	 * @param customCodePanelProxy Provides access to designer-specified
	 *                          resources, system and user-defined
	 *                          variables, and international resources.
	 *
	 * @return <code>true</code> if the Panel should be displyed,
	 *         <code>false</code> otherwise.  By default, this
	 *         method returns <code>false</code>.
	 *
	 * @see com.zerog.ia.api.pub.CustomCodePanelProxy
	 */

    public boolean setupUI(CustomCodePanelProxy ccpp)
    {
        if(!isSetup)
        {
			isSetup=true;

			final String Gradient=ccpp.substitute("$FSBGI_GRADIENT$");
			final String ImageInfo=ccpp.substitute("$FSBGI_IMAGE$");

			// if either of the variables not set tell the user so.

			if ( Gradient.equals("") || ImageInfo.equals(""))
			{
				System.out.println("One or more of the variables not set! I won't work as expected...");
			}


			BigFrame=new Window(new Frame())
			{
				public void paint(Graphics g)
				{
					// set variable to default values

					int width=d.width/255;
					int height=d.height/255;

					// set background color to Zero G blue as default

					int ColSeg[]={0,189,213,230,0,0,0};
					float RStep=0,BStep=0,GStep=0;
					int a=0,RStart=0,GStart=0,BStart=0;
					int ImageMode=-1;

					// read the color values and mode of the gradient if FSBGI_GRADIENT set

					if (!Gradient.equals(""))
					{
						StringTokenizer st=new StringTokenizer(Gradient,",");
						while (st.hasMoreTokens())
						{
							ColSeg[a]=Integer.parseInt(st.nextToken());
							a++;
						}
					}

					// read the image mode and get the image if FSBGI_IMAGE set properly.

					if (!ImageInfo.equals(""))
					{
						StringTokenizer sr=new StringTokenizer(ImageInfo,",");
						ImageMode=Integer.parseInt(sr.nextToken());

						// get image only if one is specified.

						if (ImageMode>=0)
						{
							imageURL=ClassLoader.getSystemResource(sr.nextToken());
							picture=Toolkit.getDefaultToolkit().getImage(imageURL);
						}
					}

					// set up the increment values for displaying the gradient

					RStep=((float)(ColSeg[4]-ColSeg[1]))/255;
					GStep=((float)(ColSeg[5]-ColSeg[2]))/255;
					BStep=((float)(ColSeg[6]-ColSeg[3]))/255;
					RStart=ColSeg[1];
					GStart=ColSeg[2];
					BStart=ColSeg[3];
					switch (ColSeg[0])
					{
					case 0:
						System.out.println("Setting background color...");
						setBackground(new Color(ColSeg[1],ColSeg[2],ColSeg[3]));
						break;
					case 1:
						System.out.println("Displaying Gradient top to bottom...");
						for (int x=0; x<256; x++)
						{
							g.setColor(new Color(RStart+(int)(x*RStep),GStart+(int)(x*GStep),BStart+(int)(x*BStep)));
							g.fillRect(0,x*height,d.width,height);
						}
						break;
					case 2:
						System.out.println("Displaying Gradient bottom to top...");
						for (int x=0; x<256; x++)
						{
							g.setColor(new Color(RStart+(int)(x*RStep),GStart+(int)(x*GStep),BStart+(int)(x*BStep)));
							g.fillRect(0,d.height-((x*height)+height),d.width,height);
						}
						break;
					case 3:
						System.out.println("Displaying Gradient left to right...");
						for (int x=0; x<256; x++)
						{
							g.setColor(new Color(RStart+(int)(x*RStep),GStart+(int)(x*GStep),BStart+(int)(x*BStep)));
							g.fillRect(x*width,0,width,d.height);
						}
						break;
					case 4:
						System.out.println("Displaying Gradient right to left...");
						for (int x=0; x<256; x++)
						{
							g.setColor(new Color(RStart+(int)(x*RStep),GStart+(int)(x*GStep),BStart+(int)(x*BStep)));
							g.fillRect(d.width-((x*width)+width),0,width,d.height);
						}
						break;
					default:
						break;
					}
					int pWidth=picture.getWidth(this);
					int pHeight=picture.getHeight(this);
					switch (ImageMode)
					{
					case -1:
						System.out.println("You chose not to show an image...");
						break;
					case 0:
						System.out.println("Streching image to fill screen...");
						g.drawImage(picture,0,0,d.width,d.height,this);
						break;
					case 1:
						System.out.println("Displaying image in upper left corner...");
						g.drawImage(picture,0,0,this);
						break;
					case 2:
						System.out.println("Displaying image in upper right corner...");
						g.drawImage(picture,d.width-pWidth,0,this);
						break;
					case 3:
						System.out.println("Displaying image in lower left corner...");
						g.drawImage(picture,0,d.height-pHeight,this);
						break;
					case 4:
						System.out.println("Displaying image in lower right corner...");
						g.drawImage(picture,d.width-pWidth,d.height-pHeight,this);
						break;
					case 5:
						System.out.println("Displaying image in center...");
						g.drawImage(picture,(d.width/2)-(pWidth/2),(d.height/2)-(pHeight/2),this);
						break;
					case 6:
						System.out.println("Tiling image...");
						int xlimit=(int)d.width/pWidth;
						int ylimit=(int)d.height/pHeight;
						if((d.width%pWidth)!=0)
							xlimit++;
						if((d.height%pHeight)!=0)
							ylimit++;
						for(int y=0;y<ylimit;y++)
						{
							for(int x=0;x<xlimit;x++)
							{
								g.drawImage(picture,x*pWidth,y*pHeight,this);
							}
						}
					default:
						{
						}
					}
				}
				Dimension d=Toolkit.getDefaultToolkit().getScreenSize();
				URL imageURL;
				Image picture;
			};
			Dimension d=Toolkit.getDefaultToolkit().getScreenSize();
			BigFrame.setSize(d.width,d.height);
			BigFrame.setLocation(0,0);
			BigFrame.setBackground(Color.black);
			BigFrame.show();
			//BigFrame.repaint();
			if(!System.getProperty("os.name").equals("Linux"))
				BigFrame.toFront();
			BigFrame.setEnabled(false);
			//BigFrame.setTitle(ccpp.substitute("$PRODUCT_NAME$"));
			//BigFrame.setIconImage(Toolkit.getDefaultToolkit().getImage("installIconSmall.gif"));
        }
		title = ccpp.substitute("$PRODUCT_NAME$");

        return true;
    }


	/**
	 * This method gets called immediately after the Panel is displayed.
	 * This is useful for doing some processing while the Panel is displayed,
	 * without having to wait for <code>okToContinue</code> to be called.
	 * Of course, this method will never be called if <code>setupUI()</code>
	 * returns <code>false</code> to indicate that this
	 * <code>CustomCodePanel</code> should not be displayed.
	 * The default implementation has an empty body.  Classes that extend
	 * CustomCodePanel may override this method if they wish to be notified
	 * when the Panel is displayed.
	 *
	 * The method is optional and does not need to be implemented.
	 *
	 * @see #okToContinue
	 */

	public void panelIsDisplayed()
	{
		clickNextButton();
		Component prnt=this.getParent();
		System.out.println("Walking up the parent tree..."+prnt);
		while (!(prnt instanceof Frame))
		{
			prnt=prnt.getParent();
			System.out.println(""+prnt+"\n\n");
		}
		Frame DisOne=(Frame)prnt;
		DisOne.toFront();
		if(System.getProperty("os.name").equals("Linux"))
			BigFrame.toBack();
	}

	/**
	 * This method gets called prior to continuing on with the installer.
	 * Classes that extend CustomCodePanel may wish to override this method
	 * to do some runtime checks to see if it is ok to continue with the
	 * installation process.
	 *
	 * The method is optional and does not need to be implemented.
	 *
	 * @return <code>true</code> if it ok to continue, <code>false</code>
	 *         otherwise.  By default, this method returns <code>true</code>.
	 */

	//	public boolean okToContinue()
	//	{
	//		return true;	// or false
	//	}

	/**
	 * This method returns the String to be displayed on the installation
	 * step of which this Panel will be contained.
	 *
	 */

    public String getTitle()
    {
        return title;
    }

    boolean isSetup;
    private static CustomCodePanelProxy ipGlobal;
    private static boolean installTime;
    private String title;
	Window BigFrame;
}